import re
from .numbers_list import *
def tam_above_1000(number, length):
    groups = []
    result = ''
    if length % 2 == 0:
        number = number.zfill(length+1)
    tail = number[-3:]
    head = number[:-3]
    head = [head[i:i+2] for i in range(0,len(head),2)]
    while(len(head)>0):
        groups.insert(0,head[-1:][0])
        head = head[:-1]
    groups.append(tail)
    group_length = len(groups)
    for i in groups:
        temp = tam_numbers_to_words_0_to_999(i)
        denomination = 0
        continue_flag = True
        if group_length >= 1:
            denomination = group_length - 1
            group_length -= 1
            if temp == 'பூஜ்யம்':
                continue
            for j in range(group_length,len(groups)):
                if int(groups[j]) == 0:
                    continue_flag = False

        if group_length >= 1 and continue_flag == True:
            result += temp + " " + tamil_name_formation[denomination][1] + " "
        else:
            result += temp + " " + tamil_name_formation[denomination][0] + " "
    return result
def tam_numbers_to_words_0_to_99(number, ispaise=None):
    if not ispaise:
        number = re.sub(r"^0+(?!$)", "", number)
    length = len(number)
    if length == 1:
        if ispaise:
            return tam_10_to_90[str(number)+"0"][0]
        else:
            return tam_0_to_9[str(number)]
    elif length == 2:
        if ispaise:
            number = re.sub(r"^0+(?!$)", "", number)
            if len(number) == 1:
                return tam_0_to_9[str(number)]
            elif int(number) < 20:
                return tam_10_to_19[str(number)][0]
            elif int(number) > 19:
                temp_number = str(number)[0] + '0'
                if int(str(number)[1]) > 0:
                    result = tam_10_to_90[temp_number][1] + ' ' + tam_0_to_9[str(number)[1]]
                else:
                    result = tam_10_to_90[temp_number][0]
                return result
        elif int(number) < 20:
            return tam_10_to_19[str(number)]
        elif int(number) > 19:
            temp_number = str(number)[0] + '0'
            if int(str(number)[1]) > 0:
                result = tam_10_to_90[temp_number][1] + ' ' + tam_0_to_9[str(number)[1]]
            else:
                result = tam_10_to_90[temp_number][0]
            return result
def tam_numbers_to_words_0_to_999(number):
    number = re.sub(r"^0+(?!$)", "", number)
    length = len(str(number))
    temp_number = ''
    if length < 3:
        result = tam_numbers_to_words_0_to_99(number,None)
        return result
    if length == 3:
        if int(str(number)[1]) == 0 and int(str(number)[2]) == 0:
            return tam_100_to_900[str(number)][0]

        elif int(str(number)[1]) == 0 and int(str(number)[2]) != 0:
            result = tam_100_to_900[str(number)[0] + "00"][1] + " " + tam_0_to_9[str(number)[2]]
            return result

        elif int(str(number)[1]) != 0 and int(str(number)[2]) == 0:
            result = tam_100_to_900[str(number)[0] + "00"][1] + ' ' + tam_10_to_90[str(number)[1] + "0"][0]
            return result
        else:

            result = tam_100_to_900[str(number)[0] + "00"][1] + " " + tam_10_to_90[str(number)[1] + "0"][1] + " " + tam_0_to_9[str(number)[2]]
            return result
    if length > 3:
        if number in tamil_named_numbers.keys():
            return "ஒரு " + tamil_named_numbers[number][0]
        else:
            result = tam_above_1000(number, length)
            return result


from .eng_numbers_to_words import *
from .tam_numbers_to_words import *


def num2wordsIND(inp):
    inp = str(inp)
    inp = inp.replace(",", "")
    try:
        if isinstance(float(inp), (int, float)):
            pass
    except Exception as e:
        return e, ""
    inp, decimal_number = decimal_and_real_number(inp)
    if len(inp) > 17:
        return "Maximum support is upto 17 digits", "maximum limit is 2 digits"
    if inp == '':
        inp = '0'
    rupee = eng_numbers_to_words_0_to_999(inp, True)
    rupee = rupee.rstrip()
    paise = '' or decimal_number
    if paise:
        if len(paise) > 2:
            paise = paise[:2]
        paise = eng_numbers_to_words_0_to_99(paise, True)
        return rupee, paise
    else:
        return rupee, ""


def num2wordsSI(inp):
    inp = str(inp)
    inp = inp.replace(",", "")
    try:
        if isinstance(float(inp), (int, float)):
            pass
    except Exception as e:
        return e, ""
    inp, decimal_number = decimal_and_real_number(inp)
    if len(inp) > 18:
        return "Maximum support is upto 18 digits", "maximum limit is 2 digits"
    if inp == '':
        inp = '0'
    amount = eng_numbers_to_words_0_to_999(inp, False)

    amount = amount.rstrip()
    cents = '' or decimal_number
    if cents:
        if len(cents) > 2:
            cents = cents[:2]
        cents = eng_numbers_to_words_0_to_99(cents, True)
        return amount, cents
    else:
        return amount, ""


def num2wordsTA(inp):
    inp = str(inp)
    inp = inp.replace(",", "")

    try:
        if isinstance(float(inp), (int, float)):
            pass
    except Exception as e:
        return e, ""
    inp, decimal_number = decimal_and_real_number(inp)
    if len(inp) > 18:
        return "Maximum support is upto 18 digits", "maximum limit is 2 digits"
    if inp == '':
        inp = '0'

    amount = tam_numbers_to_words_0_to_999(inp)
    amount = amount.rstrip()
    amount = re.sub(r'(ஒன்று)(?!\s*[\.\?!…“”"\'’»]*\s*$)', 'ஒரு', amount)
    cents = '' or decimal_number
    if cents:
        if len(cents) > 2:
            cents = cents[:2]
        cents = tam_numbers_to_words_0_to_99(cents, True)
        return amount, cents
    else:
        return amount, ""







from setuptools import setup, find_packages

with open("README.md", encoding="utf-8") as f:
    long_description = f.read()

setup(
    name="numbers2words",
    version="0.1",
    packages=find_packages(),
    install_requires=[],
    author="Giridharan Ponpandi",
    description="Convert numbers to words in Tamil, and English with Indian grouping and international grouping",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/GiridharanPonpandi/numbers2words.git",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)



import re

from .numbers_list import *


def decimal_and_real_number(inp):
    decimal_number = ''
    if inp.count(".") > 1:
        inp = inp.replace(".", "")
    elif inp.count(".") == 1:
        point_pos = inp.index(".")
        decimal_number = inp[point_pos + 1:]
        inp = re.sub(r"\..*", "", inp)
    elif inp.count(".") > 1:
        inp.replace(".", "")
    return inp, decimal_number
def eng_IND_above_1000(number, length):
    groups = []
    result = ''
    if length % 2 == 0:
        number = number.zfill(length+1)
    tail = number[-3:]
    head = number[:-3]
    head = [head[i:i+2] for i in range(0,len(head),2)]
    while(len(head)>0):
        groups.insert(0,head[-1:][0])
        head = head[:-1]
    groups.append(tail)
    group_length = len(groups)
    for i in groups:
        temp = eng_numbers_to_words_0_to_999(i,True)
        denomination = 0
        if group_length >= 1:
            denomination = group_length - 1
            group_length -= 1
            if temp == 'zero':
                continue
        result += temp +" " +indian_eng_above_thousand[denomination] + " "

    return result
def eng_SI_above_1000(number,length):
    groups = []
    result = ''
    zfill_num = [0,2,1]
    if length % 3 != 0:
        number = number.zfill(length + (zfill_num[length%3]))
    groups = [number[i:i+3] for i in range(0,len(number),3)]
    group_length = len(groups)
    for i in groups:
        temp = eng_numbers_to_words_0_to_999(i,True)
        denomination = 0
        if group_length >= 1:
            denomination = group_length - 1
            group_length -= 1
            if temp == 'zero':
                continue
        result += temp +" " +standard_international_eng_above_thousand[denomination] + " "

    return result
    pass
def eng_numbers_to_words_0_to_99(number, ispaise=None):
    if not ispaise:
        number = re.sub(r"^0+(?!$)", "", number)
    length = len(number)
    if length == 1:
        if ispaise:
            return eng_10_to_90[str(number)+"0"]
        return eng_0_to_9[str(number)]
    elif length == 2:
        if ispaise:
            number = re.sub(r"^0+(?!$)", "", number)
            if len(number) == 1:
                return eng_0_to_9[str(number)]
            elif int(number) < 20:
                return eng_10_to_19[str(number)]
            elif int(number) > 19:
                temp_number = str(number)[0] + '0'
                if int(str(number)[1]) > 0:
                    result = eng_10_to_90[temp_number] + ' ' + eng_0_to_9[str(number)[1]]
                else:
                    result = eng_10_to_90[temp_number]
                return result
        elif int(number) < 20:
            return eng_10_to_19[str(number)]
        elif int(number) > 19:
            temp_number = str(number)[0] + '0'
            if int(str(number)[1]) > 0:
                result = eng_10_to_90[temp_number] + ' ' + eng_0_to_9[str(number)[1]]
            else:
                result = eng_10_to_90[temp_number]
            return result

def eng_numbers_to_words_0_to_999(number,flag):
    number = re.sub(r"^0+(?!$)", "", number)
    length = len(str(number))
    temp_number = ''
    if length < 3:
        result = eng_numbers_to_words_0_to_99(number)
        return result
    if length == 3:
        if int(str(number)[1]) == 0 and int(str(number)[2]) == 0:
            return eng_100_to_900[str(number)]

        elif int(str(number)[1]) == 0 and int(str(number)[2]) != 0:
            result = eng_100_to_900[str(number)[0] + "00"] + " " + "and" + " " + eng_0_to_9[str(number)[2]]
            return result

        elif int(str(number)[1]) != 0 and int(str(number)[2]) == 0:


            result = eng_100_to_900[str(number)[0] + "00"] + ' ' + "and" + " " + eng_10_to_90[str(number)[1] + "0"]
            return result
        else:
            if int(str(number)[1]) == 1:
                result = eng_100_to_900[str(number)[0] + "00"] + ' ' + "and" + " " + eng_10_to_19[str(number)[1] + str(number)[1]]
                return result
            else:
                result = eng_100_to_900[str(number)[0] + "00"] + ' '+ "and" + " " + eng_10_to_90[str(number)[1] + "0"] + " " + eng_0_to_9[str(number)[2]]
            return result
    if length > 3:
        if flag:
            result = eng_IND_above_1000(number, length)
        else:
            result = eng_SI_above_1000(number,length)
        return result